package com.tzld.longarticle.recommend.server.service.filter.strategy;

import com.google.common.collect.Sets;
import com.tzld.longarticle.recommend.server.model.Content;
import com.tzld.longarticle.recommend.server.service.AccountContentPoolConfigService;
import com.tzld.longarticle.recommend.server.service.filter.FilterParam;
import com.tzld.longarticle.recommend.server.service.filter.FilterResult;
import com.tzld.longarticle.recommend.server.service.filter.FilterStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * @author dyp
 */
@Component
@Slf4j
public class AccountStrategy implements FilterStrategy {
    @Autowired
    private AccountContentPoolConfigService accountContentPoolConfigService;

    @Override
    public FilterResult filter(FilterParam param) {
        FilterResult filterResult = new FilterResult();
        List<String> result = new ArrayList<>();
        List<Content> contents = param.getContents();
        List<Content> filterContents = new ArrayList<>();
        String[] pools = accountContentPoolConfigService.getContentPools(param.getAccountName());
        Set<String> poolSet = Sets.newHashSet(pools);
        for (Content content : contents) {
            if (poolSet.contains(content.getContentPoolType())) {
                result.add(content.getId());
            } else {
                content.setFilterReason("账号不支持该内容池");
                filterContents.add(content);
            }
        }
        filterResult.setContentIds(result);
        filterResult.setFilterContent(filterContents);
        return filterResult;
    }

}
